@@ -74,6 +74,7 @@ pub use build::ConsensusBuilder;
 pub use rs::build::RouterStatusBuilder;
 
 pub use rs::MdConsensusRouterStatus;
+#[cfg(feature = "ns_consensus")]
 pub use rs::NsConsensusRouterStatus;
 
 /// The lifetime of a networkstatus document.
@@ -141,7 +142,7 @@ impl Lifetime {
 /// These are used to describe current settings for the Tor network,
 /// current weighting parameters for path selection, and so on.  They're
 /// encoded with a space-separated K=V format.
-#[derive(Debug, Clone, Default)]
+#[derive(Debug, Clone, Default, Eq, PartialEq)]
 pub struct NetParams<T> {
     /// Map from keys to values.
     params: HashMap<String, T>,
@@ -326,13 +327,12 @@ struct ConsensusHeader {
 struct DirSource {
     /// human-readable nickname for this authority.
     nickname: String,
-    /// DOCDOC -- I forget.  Is this the identity fingerprint for the
-    /// authority identity key, or for the identity key of the authority
-    /// when it's running as a relay?
+    /// Fingerprint for the _authority_ identity key of this
+    /// authority.
+    ///
+    /// This is the same key as the one that signs the authority's
+    /// certificates.
     identity: RsaIdentity,
-    /// Address of the authority in string form.
-    // XXXX why do we have this _and_ IP?
-    address: String,
     /// IP address for the authority
     ip: net::IpAddr,
     /// HTTP directory port for this authority
@@ -499,14 +499,17 @@ pub type UnvalidatedMdConsensus = UnvalidatedConsensus<MdConsensusRouterStatus>;
 /// and timeliness.
 pub type UncheckedMdConsensus = UncheckedConsensus<MdConsensusRouterStatus>;
 
+#[cfg(feature = "ns_consensus")]
 /// A consensus document that lists relays along with their
 /// router descriptor documents.
 pub type NsConsensus = Consensus<NsConsensusRouterStatus>;
 
+#[cfg(feature = "ns_consensus")]
 /// An NsConsensus that has been parsed and checked for timeliness,
 /// but not for signatures.
 pub type UnvalidatedNsConsensus = UnvalidatedConsensus<NsConsensusRouterStatus>;
 
+#[cfg(feature = "ns_consensus")]
 /// An NsConsensus that has been parsed but not checked for signatures
 /// and timeliness.
 pub type UncheckedNsConsensus = UncheckedConsensus<NsConsensusRouterStatus>;
@@ -929,7 +932,6 @@ impl DirSource {
         }
         let nickname = item.required_arg(0)?.to_string();
         let identity = item.parse_arg::<Fingerprint>(1)?.into();
-        let address = item.required_arg(2)?.to_string();
         let ip = item.parse_arg(3)?;
         let dir_port = item.parse_arg(4)?;
         let or_port = item.parse_arg(5)?;
@@ -937,7 +939,6 @@ impl DirSource {
         Ok(DirSource {
             nickname,
             identity,
-            address,
             ip,
             dir_port,
             or_port,
@@ -1457,7 +1458,7 @@ impl SignatureGroup {
     fn list_missing(&self, certs: &[AuthCert]) -> (usize, Vec<&Signature>) {
         let mut ok: HashSet<RsaIdentity> = HashSet::new();
         let mut missing = Vec::new();
-        for sig in self.signatures.iter() {
+        for sig in &self.signatures {
             let id_fingerprint = &sig.key_ids.id_fingerprint;
             if ok.contains(id_fingerprint) {
                 continue;
@@ -1477,7 +1478,7 @@ impl SignatureGroup {
     /// authorities.
     fn could_validate(&self, authorities: &[&RsaIdentity]) -> bool {
         let mut signed_by: HashSet<RsaIdentity> = HashSet::new();
-        for sig in self.signatures.iter() {
+        for sig in &self.signatures {
             let id_fp = &sig.key_ids.id_fingerprint;
             if signed_by.contains(id_fp) {
                 // Already found this in the list.
@@ -1503,7 +1504,7 @@ impl SignatureGroup {
         // than one certificate for a single authority.
         let mut ok: HashSet<RsaIdentity> = HashSet::new();
 
-        for sig in self.signatures.iter() {
+        for sig in &self.signatures {
             let id_fingerprint = &sig.key_ids.id_fingerprint;
             if ok.contains(id_fingerprint) {
                 // We already checked at least one signature using this
@@ -1545,7 +1546,9 @@ mod test {
     const CERTS: &str = include_str!("../../testdata/authcerts2.txt");
     const CONSENSUS: &str = include_str!("../../testdata/mdconsensus1.txt");
 
+    #[cfg(feature = "ns_consensus")]
     const NS_CERTS: &str = include_str!("../../testdata/authcerts3.txt");
+    #[cfg(feature = "ns_consensus")]
     const NS_CONSENSUS: &str = include_str!("../../testdata/nsconsensus1.txt");
 
     fn read_bad(fname: &str) -> String {
@@ -1626,6 +1629,7 @@ mod test {
     }
 
     #[test]
+    #[cfg(feature = "ns_consensus")]
     fn parse_and_validate_ns() -> Result<()> {
         use tor_checkable::{SelfSigned, Timebound};
         let mut certs = Vec::new();
@@ -1644,7 +1648,7 @@ mod test {
         assert!(consensus.authorities_are_correct(&auth_ids[0..1]));
 
         assert!(consensus.key_is_correct(&certs).is_ok());
-        dbg!("FOO");
+
         let _consensus = consensus.check_signature(&certs)?;
 
         Ok(())
