@@ -27,6 +27,11 @@
 //! TODO: There should be accessor functions for some or all of the
 //! fields in RouterDesc.  I'm deferring those until I know what they
 //! should be.
+//!
+//! # Availability
+//!
+//! Most of this module is only available when this crate is built with the
+//! `routerdesc` feature enabled.
 use crate::parse::keyword::Keyword;
 use crate::parse::parser::{Section, SectionRules};
 use crate::parse::tokenize::{ItemResult, NetDocReader};
@@ -44,6 +49,7 @@ use tor_llcrypto as ll;
 use tor_llcrypto::pk::rsa::RsaIdentity;
 
 use digest::Digest;
+#[allow(unused_imports)] // This 'use' is needed with ed25519 < 1.3.0
 use signature::Signature;
 
 /// The digest of a RouterDesc document, as reported in a NS consensus.
