@@ -24,6 +24,17 @@
 //! inside directory documents.  Finally, the [`doc`] module defines
 //! the parsers for the documents themselves.
 //!
+//! # Features
+//!
+//! `build_docs`: enable code to construct the objects representing different
+//! network documents.
+//!
+//! `routerdesc`: enable support for the "router descriptor" document type, which
+//! is needed by bridge clients and relays.
+//!
+//! `ns-consensus`: enable support for the "ns consensus" document type, which
+//! some relays cache and serve.
+//!
 //! # Caveat haxxor: limitations and infelicities
 //!
 //! TODO: This crate requires that all of its inputs be valid UTF-8:
@@ -63,6 +74,7 @@
 #![warn(clippy::option_option)]
 #![warn(clippy::rc_buffer)]
 #![deny(clippy::ref_option_ref)]
+#![warn(clippy::semicolon_if_nothing_returned)]
 #![warn(clippy::trait_duplication_in_bounds)]
 #![deny(clippy::unnecessary_wraps)]
 #![warn(clippy::unseparated_literal_suffix)]
